@@ -1,10 +1,11 @@
 "krige" <-
 function (formula, locations, data = sys.frame(sys.parent()), 
-	newdata, model = NULL, beta = NULL, nmax = Inf, maxdist = Inf,
-	block = numeric(0), nsim = 0, indicators = FALSE, ...)
+	newdata, model = NULL, beta = NULL, nmax = Inf, nmin = 0, 
+	maxdist = Inf, block = numeric(0), nsim = 0, indicators = FALSE, ...)
 {
     g = gstat(formula = formula, locations = locations, model = model,
-		data = data, beta = beta, nmax = nmax, maxdist = maxdist, ...)
+		data = data, beta = beta, nmax = nmax, nmin = nmin, 
+		maxdist = maxdist, ...)
     predict.gstat(g, newdata = newdata, block = block, nsim = nsim,
 	indicators = indicators)
 }
