@@ -1,7 +1,9 @@
-".First.lib" <-
+.onLoad <-
 function(lib, pkg) {
-	require(lattice)
 	library.dynam("gstat", pkg, lib)
 	.Call("gstat_init", as.integer(1), PACKAGE = "gstat")
+	require(lattice)
 }
+
+
 variogram <- function(object, ...) UseMethod("variogram")
